/*
 * table.h --
 *
 *      Datatype to store contents of a mib table- 
 *
 * Copyright (c) 2002 T. Klie, Technical University of Braunschweig.
 *
 * See the file "COPYING" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * @(#) $Id: table.h,v 1.9 2004/07/06 10:41:18 tklie Exp $
 */

#ifndef _MIBDUMP_TABLE_H
#define _MIBDUMP_TABLE_H

#include <netinet/in.h>

#ifdef HAVE_NET_SNMP_NET_SNMP_CONFIG_H
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#else
#include <ucd-snmp/ucd-snmp-config.h>
#include <ucd-snmp/ucd-snmp-includes.h>
#endif

#include <smi.h>

#ifndef MIN
#define MIN(a,b) ((a)) < ((b)) ? ((a)) : ((b))
#endif /* #ifndef MIN */

#ifndef MAX
#define MAX(a,b) ((a)) > ((b)) ? ((a)) : ((b))
#endif /* MAX */

/* column list */
typedef struct MDCol {
    oid col;
    char *value;
    struct MDCol *next;
    struct MDRow *subRow;
    SmiNode *smiNode;
} MDCol;

/* row list */
typedef struct MDRow {
    oid *index;
    int index_len;
    MDCol *columns;
    struct MDRow *next;
} MDRow;

/* info about augmentations */
typedef struct MDAugment {
    unsigned int startCol;
    SmiNode *smiNode;
    struct MDAugment *next;
} MDAugment;

/* table */
typedef struct MDTable {
    oid *prefix;
    int prefix_len;
    char *name;    
    MDRow *rows;
    unsigned int maxColNum;
    MDAugment *augmentations;
} MDTable;

/* table operations */
struct MDTable *md_createTable( char *name,
				oid *prefix, unsigned int prefix_len );
MDRow *md_addRow( MDTable *table, oid *index, unsigned int index_len );
MDRow *md_findRow( MDTable *table, oid *index, unsigned int index_len );
MDCol *md_addColumn( MDRow *row, oid col, char *value );
MDCol *md_findColumn( MDRow *row, oid col );
unsigned int md_numColumns( MDRow *row );
MDAugment *md_getAugment( MDTable *table, MDCol *col );
void md_addSubTable( MDTable *table, char *name,
		     oid *prefix, unsigned int prefix_len );
void md_dropTable( MDTable *table );

#endif /* #infdef _MIBDUMP_TABLE_H */
